﻿/* License
 * This work is licensed under the Creative Commons Attribution 2.5 License
 * http://creativecommons.org/licenses/by/2.5/

 * You are free:
 *     to copy, distribute, display, and perform the work
 *     to make derivative works
 *     to make commercial use of the work
 * 
 * Under the following conditions:
 *     You must attribute the work in the manner specified by the author or licensor:
 *          - If you find this component useful a email to [sobne.cn@gmail.com] would be appreciated.
 *     For any reuse or distribution, you must make clear to others the license terms of this work.
 *     Any of these conditions can be waived if you get permission from the copyright holder.
 * 
 * Copyright sobne.cn All Rights Reserved.
*/
using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using Utility4Net.Expression;

namespace Utility4Net
{
    /// <summary>
    /// Extension方法
    /// </summary>
    public static class StaticExtension
    {
        /// <summary>
        /// 是否正确的E-Mail地址
        /// </summary>
        /// <param name="sEmail">需要检测的E-Mail地址串</param>
        /// <returns>boolen值</returns>
        public static bool IsValidEmailAddress(this string sEmail)
        {
            Regex regex = new Regex(RegularExpressions.EMAIL);
            return regex.Match(sEmail).Success;
        }
        /// <summary>
        /// 将字符串转换为list
        /// </summary>
        /// <typeparam name="T">List类型</typeparam>
        /// <param name="str">字符串</param>
        /// <param name="split">分隔符</param>
        /// <param name="convertHandler">类型转换</param>
        /// <returns>List</returns>
        public static List<T> ToList<T>(this string str, string split, Converter<string, T> convertHandler)
        {
            if (string.IsNullOrEmpty(str))
                return new List<T>();
            else
            {
                string[] arr = str.Split(new char[] { Convert.ToChar(split) });
                T[] Tarr = Array.ConvertAll(arr, convertHandler);
                return new List<T>(Tarr);
            }
        }
        #region int
        /// <summary>
        /// 检测输入字符串是否是有效的32位整数
        /// </summary>
        /// <param name="s">输入字符串</param>
        /// <returns>Boolen值</returns>
        public static bool IsInt(this string s)
        {
            int i;
            return int.TryParse(s, out i);
        }
        /// <summary>
        /// 将数字的字符串表示形式转换为它的等效 32 位有符号整数
        /// </summary>
        /// <param name="s">包含要转换的数字的字符串</param>
        /// <returns>与 s 中包含的数字等效的 32 位有符号整数</returns>
        public static int ToInt(this string s)
        {
            return int.Parse(s);
        }
        /// <summary>
        /// 将数字的字符串表示形式转换为它的等效 32 位有符号整数
        /// </summary>
        /// <param name="s">包含要转换的数字的字符串</param>
        /// <param name="defaultValue">默认值</param>
        /// <returns></returns>
        public static int ToInt(this string s, int defaultValue)
        {
            if (s.IsInt())
                return int.Parse(s);
            else
                return defaultValue;
        }
        #endregion
        #region float
        /// <summary>
        /// 检测输入字符串是否是有效的32位浮点数
        /// </summary>
        /// <param name="s">输入字符串</param>
        /// <returns>Boolen值</returns>
        public static bool IsFloat(this string s)
        {
            float i;
            return float.TryParse(s, out i);
        }
        /// <summary>
        /// 将数字的字符串表示形式转换为它的等效单精度浮点数字
        /// </summary>
        /// <param name="s">包含要转换的数字的字符串</param>
        /// <returns>与 s 中指定的数值或符号等效的单精度浮点数字</returns>
        public static float ToFloat(this string s)
        {
            return float.Parse(s);
        }
        /// <summary>
        /// 将数字的字符串表示形式转换为它的等效单精度浮点数字
        /// </summary>
        /// <param name="s">包含要转换的数字的字符串</param>
        /// <param name="defaultValue">默认值</param>
        /// <returns></returns>
        public static float ToFloat(this string s, float defaultValue)
        {
            if (s.IsFloat())
                return s.ToFloat();
            else
                return defaultValue;
        }
        #endregion
        #region string
        /// <summary>
        /// 字符串是否为空
        /// </summary>
        /// <param name="s">需要检测的字符串</param>
        /// <returns>boolen值</returns>
        public static bool IsNullOrEmpty(this string s)
        {
            return string.IsNullOrEmpty(s);
        }
        #endregion

        #region Regex
        /// <summary>
        /// 指示所指定的正则表达式在指定的输入字符串中是否找到了匹配项。
        /// </summary>
        /// <param name="s">要搜索匹配项的字符串</param>
        /// <param name="pattern">要匹配的正则表达式模式</param>
        /// <returns>如果正则表达式找到匹配项，则为 true；否则，为 false</returns>
        public static bool IsMatch(this string s, string pattern)
        {
            return (s == null) ? false : Regex.IsMatch(s, pattern);
        }
        /// <summary>
        /// 在指定的输入字符串中搜索指定的正则表达式的第一个匹配项
        /// </summary>
        /// <param name="s">要搜索匹配项的字符串</param>
        /// <param name="pattern">要匹配的正则表达式模式</param>
        /// <returns>一个对象，包含有关匹配项的信息</returns>
        public static string Match(this string s, string pattern)
        {
            return (s == null) ? "" : Regex.Match(s, pattern).Value;
        }
        #endregion
    }
}
